.. -*- mode: rst ; ispell-local-dictionary: "american" -*-


git flow |BRANCH| track - Track a |BRANCH| branch from a remote peer
=======================================================================


Synopsis
-----------

.. parsed-literal::

  `git flow` |`BRANCH`| `track` version


Description
-----------

Start tracking a |BRANCH| branch, with the given version, from
``origin`` (or whatever is configured as ``remote`` for gitflow.)


Positional arguments
-----------------------

  :version:      Version of the |BRANCH| branch to track.


Options
-----------

  -h, --help          Show help message and exit.
